import { type EditorView, Tooltip } from "@codemirror/view";
import { type Draft, JsonSchema } from "json-schema-library";
import type { JSONSchema7 } from "json-schema";
import { Side } from "./types";
export type CursorData = {
    schema?: JsonSchema;
    pointer: string;
};
export type FoundCursorData = Required<CursorData>;
export type HoverTexts = {
    message: string;
    typeInfo: string;
};
export type HoverOptions = {
    /**
     * Generate the text to display in the hover tooltip
     */
    getHoverTexts?: (data: FoundCursorData) => HoverTexts;
    /**
     * Generate the hover tooltip HTML
     */
    formatHover?: (data: HoverTexts) => HTMLElement;
    /**
     * Provide a custom parser for the document
     * @default JSON.parse
     */
    parser?: (text: string) => any;
};
/**
 * provides a JSON schema enabled tooltip extension for codemirror
 * @group Codemirror Extensions
 */
export declare function jsonSchemaHover(schema: JSONSchema7, options?: HoverOptions): (view: EditorView, pos: number, side: Side) => Promise<Tooltip | null>;
export declare class JSONHover {
    private opts?;
    private schema;
    constructor(schema: JSONSchema7, opts?: HoverOptions | undefined);
    getDataForCursor(view: EditorView, pos: number, side: Side): CursorData | null;
    private formatMessage;
    getHoverTexts(data: FoundCursorData, draft: Draft): HoverTexts;
    doHover(view: EditorView, pos: number, side: Side): Promise<Tooltip | null>;
}
