import { syntaxTree } from "@codemirror/language";
import { TOKENS } from "../constants";
import { findNodeIndexInArrayNode, getWord, isValueNode } from "./node";
// adapted from https://discuss.codemirror.net/t/json-pointer-at-cursor-seeking-implementation-critique/4793/3
// this could be useful for other things later!
export function getJsonPointerAt(docText, node) {
    const path = [];
    for (let n = node; n === null || n === void 0 ? void 0 : n.parent; n = n.parent) {
        switch (n.parent.name) {
            case TOKENS.PROPERTY: {
                const name = n.parent.getChild(TOKENS.PROPERTY_NAME);
                if (name) {
                    path.unshift(getWord(docText, name).replace(/[/~]/g, (v) => v === "~" ? "~0" : "~1"));
                }
                break;
            }
            case TOKENS.ARRAY: {
                if (isValueNode(n)) {
                    const index = findNodeIndexInArrayNode(n.parent, n);
                    path.unshift(`${index}`);
                }
                break;
            }
        }
    }
    path.unshift("");
    return path.join("/");
}
/**
 * retrieve a JSON pointer for a given position in the editor
 * @group Utilities
 */
export const jsonPointerForPosition = (state, pos, side = -1) => {
    return getJsonPointerAt(state.doc, syntaxTree(state).resolve(pos, side));
};
/**
 * retrieve a Map of all the json pointers in a document
 * @group Utilities
 */
export const getJsonPointers = (state, mode = "json4") => {
    const json = syntaxTree(state);
    const pointers = new Map();
    json.iterate({
        enter: (type) => {
            var _a, _b, _c, _d, _e, _f, _g, _h;
            if (type.name === "PropertyName") {
                const pointer = getJsonPointerAt(state.doc, type.node);
                const { from: keyFrom, to: keyTo } = type.node;
                // if there's no value, we can't get the valueFrom/to
                if (!((_b = (_a = type.node) === null || _a === void 0 ? void 0 : _a.nextSibling) === null || _b === void 0 ? void 0 : _b.node)) {
                    pointers.set(pointer, { keyFrom, keyTo });
                    return true;
                }
                const nextNode = mode === "json4"
                    ? (_d = (_c = type.node) === null || _c === void 0 ? void 0 : _c.nextSibling) === null || _d === void 0 ? void 0 : _d.node
                    : (_h = (_g = (_f = (_e = type.node) === null || _e === void 0 ? void 0 : _e.nextSibling) === null || _f === void 0 ? void 0 : _f.node) === null || _g === void 0 ? void 0 : _g.nextSibling) === null || _h === void 0 ? void 0 : _h.node;
                if (!nextNode) {
                    pointers.set(pointer, { keyFrom, keyTo });
                    return true;
                }
                const { from: valueFrom, to: valueTo } = nextNode;
                pointers.set(pointer, { keyFrom, keyTo, valueFrom, valueTo });
                return true;
            }
        },
    });
    return pointers;
};
